@@ -115,7 +115,7 @@ sub prepare_body {
 
     if ($bug) {
         $body = "We have the following bug reported to the Debian package "
-            . "of $opt_dist ($info->{url}):" . "\n";
+            . "of $opt_dist, c.f. $info->{url}" . "\n";
         $body .= "\nIt doesn't seem to be a bug in the packaging, "
             . "so you may want to take a look. Thanks!\n";
         $body = wrap( '', '', $body );
